@@ -35,7 +35,7 @@ class SetAudioLanguageAction(gaupol.RadioAction):
 class VolumeDownAction(gaupol.Action):
     def __init__(self):
         gaupol.Action.__init__(self, "volume-down")
-        self.accelerators = ["<Ctrl>minus", "<Ctrl>KP_Subtract"]
+        self.accelerators = ["<Control>minus", "<Control>KP_Subtract"]
         self.action_group = "unsafe"
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(application.player is not None)
@@ -44,7 +44,7 @@ class VolumeDownAction(gaupol.Action):
 class VolumeUpAction(gaupol.Action):
     def __init__(self):
         gaupol.Action.__init__(self, "volume-up")
-        self.accelerators = ["<Ctrl>plus", "<Ctrl>KP_Add"]
+        self.accelerators = ["<Control>plus", "<Control>KP_Add"]
         self.action_group = "unsafe"
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(application.player is not None)
